@@ -854,10 +854,8 @@ def make_rebalance(start_date, end_date, optimizer, portfolio_input, rebalance,
     
     for i in range(len(dates) - 1):
     
-        print(optimizer)
-        type(optimizer)
-        
-        if optimizer == "BL":
+
+        if str(optimizer) == "BL":
           portfolio = Engine(
             start_date = dates[0],
             end_date = dates[i+1],
